@@ -10,16 +10,6 @@ our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
 use vars qw/$VERSION/;
 use Config;
-#
-# It is difficult to make perl communicate with other languages using
-# a "native" type, and the only unambiguous thingies are:
-# - undef (managed directly the XS)
-# - strict number (uses Types::Standard)
-# - integer (subset of the above)
-# - string is sort of catch-all fallback for scalars
-# - else data will remain opaque to perl
-#
-use Types::Standard qw//;
 
 #
 # Internal routine used at bootstrap that says is nvtype is a double
@@ -49,7 +39,7 @@ BEGIN {
 # Bootstrap
 #
 BEGIN {
-    our $VERSION = '3.0.6'; # VERSION
+    our $VERSION = '3.0.7'; # VERSION
 
     require XSLoader;
     XSLoader::load(__PACKAGE__, $VERSION);
@@ -134,13 +124,6 @@ sub DESTROY {
 sub is_bool { goto \&JSON::MaybeXS::is_bool }
 
 
-sub is_Int       { goto \&Types::Standard::is_Int }
-sub is_StrictNum { goto \&Types::Standard::is_StrictNum }
-
-
-sub is_Str { goto \&Types::Standard::is_Str }
-
-
 1;
 
 __END__
@@ -155,7 +138,7 @@ MarpaX::ESLIF - ESLIF is Extended ScanLess InterFace
 
 =head1 VERSION
 
-version 3.0.6
+version 3.0.7
 
 =head1 SYNOPSIS
 
@@ -252,13 +235,17 @@ Defaults to C<JSON::MaybeXS::is_bool($value)>
 
 =back
 
-=head2 NUMERIC TYPES
+=head2 INTEGER TYPE
 
-ESLIF has two functions C<MarpaX::ESLIF::is_Int()> and C<MarpaX::ESLIF::is_StrictNum()>, that maps by default to the L<Types::Standard> implementations. You may localize them before using ESLIF if needed.
+ESLIF consider scalars that have only the internal IV flag.
+
+=head2 FLOAT TYPE
+
+ESLIF consider scalars that have only the internal NV flag.
 
 =head2 STRING TYPE
 
-ESLIF has the function C<MarpaX::ESLIF::is_Str()>, that maps by default to the L<Types::Standard> implementation. You may localize it before using ESLIF if needed.
+ESLIF consider scalars that have only the internal PV flag.
 
 =head1 SEE ALSO
 
